package com.gprinter.utils;

import android.util.Log;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.io.LineNumberReader;
import java.util.Iterator;
import java.util.Vector;

/* loaded from: com_gprinter_utils.jar:com/gprinter/utils/SerialPortFinder.class */
public class SerialPortFinder {
    private static final String TAG = SerialPortFinder.class.getSimpleName();
    private Vector<Driver> mDrivers = null;

    /* loaded from: com_gprinter_utils.jar:com/gprinter/utils/SerialPortFinder$Driver.class */
    public class Driver {
        private String mDriverName;
        private String mDeviceRoot;
        Vector<File> mDevices = null;

        public Driver(String name, String root) {
            this.mDriverName = name;
            this.mDeviceRoot = root;
        }

        public Vector<File> getDevices() {
            if (this.mDevices == null) {
                this.mDevices = new Vector<>();
                File dev = new File("/dev");
                File[] files = dev.listFiles();
                if (files == null) {
                    return null;
                }
                for (int i = 0; i < files.length; i++) {
                    if (files[i].getAbsolutePath().startsWith(this.mDeviceRoot)) {
                        Log.d(SerialPortFinder.TAG, "???? Found new device: " + files[i]);
                        this.mDevices.add(files[i]);
                    }
                }
            }
            return this.mDevices;
        }

        public String getName() {
            return this.mDriverName;
        }
    }

    Vector<Driver> getDrivers() throws IOException {
        if (this.mDrivers == null) {
            this.mDrivers = new Vector<>();
            LineNumberReader r = new LineNumberReader(new FileReader("/proc/tty/drivers"));
            while (true) {
                String l = r.readLine();
                if (l == null) {
                    break;
                }
                String drivername = l.substring(0, 21).trim();
                String[] w = l.split(" +");
                if (w.length >= 5 && w[w.length - 1].equals("serial")) {
                    Log.d(TAG, "???? Found new driver " + drivername + " on " + w[w.length - 4]);
                    this.mDrivers.add(new Driver(drivername, w[w.length - 4]));
                }
            }
            r.close();
        }
        return this.mDrivers;
    }

    public String[] getAllDevices() {
        Vector<String> devices = new Vector<>();
        try {
            Iterator<Driver> itdriv = getDrivers().iterator();
            while (itdriv.hasNext()) {
                Driver driver = itdriv.next();
                Vector<File> files = driver.getDevices();
                if (files == null) {
                    return null;
                }
                Iterator<File> it = files.iterator();
                while (it.hasNext()) {
                    File file = it.next();
                    String device = file.getName();
                    String value = String.format("%s (%s)", device, driver.getName());
                    devices.add(value);
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return (String[]) devices.toArray(new String[devices.size()]);
    }

    public String[] getAllDevicesPath() {
        Vector<String> devices = new Vector<>();
        try {
            Iterator<Driver> itdriv = getDrivers().iterator();
            while (itdriv.hasNext()) {
                Driver driver = itdriv.next();
                Vector<File> files = driver.getDevices();
                if (files == null) {
                    return null;
                }
                Iterator<File> it = files.iterator();
                while (it.hasNext()) {
                    File file = it.next();
                    String device = file.getAbsolutePath();
                    devices.add(device);
                }
            }
        } catch (IOException e) {
            e.printStackTrace();
        }
        return (String[]) devices.toArray(new String[devices.size()]);
    }
}
